@@ -52,6 +52,13 @@ columns:
     - invalid_percentage == 0
 excluded_columns:
 - date
+sql_metrics:
+- sql: |
+    SELECT sum(size) as total_size_us
+    FROM demodata
+    WHERE country = 'US'
+  tests:
+  - total_size_us > 5000
 """
 
 
@@ -254,7 +261,7 @@ def test_scan_execute_with_metric_groups_measurement_as_expected(
             ),
             passed=True,
             skipped=False,
-            values={"row_count": 6},
+            values={"expression_result": 6, "row_count": 6},
             error=None,
             group_values=None,
         ),
@@ -268,7 +275,7 @@ def test_scan_execute_with_metric_groups_measurement_as_expected(
             ),
             passed=True,
             skipped=False,
-            values={"invalid_percentage": 0.0},
+            values={"expression_result": 0.0, "invalid_percentage": 0.0},
             error=None,
         ),
         TestResult(
@@ -281,7 +288,21 @@ def test_scan_execute_with_metric_groups_measurement_as_expected(
             ),
             passed=True,
             skipped=False,
-            values={"invalid_percentage": 0.0},
+            values={"expression_result": 0.0, "invalid_percentage": 0.0},
+            error=None,
+            group_values=None,
+        ),
+        TestResult(
+            test=Test(
+                id='{"sql_metric_index":0,"expression":"total_size_us > 5000"}',
+                title="sqlmetric(0) test(total_size_us > 5000)",
+                expression="total_size_us > 5000",
+                metrics=["total_size_us"],
+                column=None,
+            ),
+            passed=True,
+            skipped=False,
+            values={"expression_result": 11553, "total_size_us": 11553},
             error=None,
             group_values=None,
         ),
